@@ -110,6 +110,14 @@ class ChimeSDKMeetingsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/chime-sdk-meetings.html#ChimeSDKMeetings.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_meetings/client/#close)
+        """
+
     def create_attendee(
         self,
         *,
@@ -133,7 +141,8 @@ class ChimeSDKMeetingsClient(BaseClient):
         MeetingHostId: str = ...,
         NotificationsConfiguration: NotificationsConfigurationTypeDef = ...,
         MeetingFeatures: MeetingFeaturesConfigurationTypeDef = ...,
-        PrimaryMeetingId: str = ...
+        PrimaryMeetingId: str = ...,
+        TenantIds: Sequence[str] = ...
     ) -> CreateMeetingResponseTypeDef:
         """
         Creates a new Amazon Chime SDK meeting in the specified media Region with no
@@ -153,7 +162,8 @@ class ChimeSDKMeetingsClient(BaseClient):
         MeetingHostId: str = ...,
         MeetingFeatures: MeetingFeaturesConfigurationTypeDef = ...,
         NotificationsConfiguration: NotificationsConfigurationTypeDef = ...,
-        PrimaryMeetingId: str = ...
+        PrimaryMeetingId: str = ...,
+        TenantIds: Sequence[str] = ...
     ) -> CreateMeetingWithAttendeesResponseTypeDef:
         """
         Creates a new Amazon Chime SDK meeting in the specified media Region, with
