@@ -80,6 +80,7 @@ TranscribeRegionType = Literal[
     "sa-east-1",
     "us-east-1",
     "us-east-2",
+    "us-gov-west-1",
     "us-west-2",
 ]
 TranscribeVocabularyFilterMethodType = Literal["mask", "remove", "tag"]
@@ -154,6 +155,7 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
     "connectparticipant",
     "cur",
     "customer-profiles",
@@ -264,6 +266,7 @@ ServiceName = Literal[
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -320,11 +323,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
